# Functional Programming in Python, for Education

Python has some support for functional programming:
* functions are first-class citizens;
* functions can take functions as arguments and can return functions
* lambda expressions for anonymous functions

FuPy aims to overcome some limitations.

To be released soon.
